.. currentmodule:: sardana.pool

.. _sardana-pseudocounter-overview:

=======================
Pseudo counter overview
=======================

.. todo:: document pseudo counter overview

.. seealso:: 
    
    :ref:`sardana-pseudocounter-api`
        the pseudo counter :term:`API` 
    
    :class:`~sardana.tango.pool.PseudoCounter.PseudoCounter`
        the pseudo counter tango device :term:`API`
